@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -67,7 +67,7 @@ void SCIPnlhdlrSetFreeHdlrData(
 /** sets the nonlinear handler callback to free expression specific data of nonlinear handler */
 SCIP_EXPORT
 void SCIPnlhdlrSetFreeExprData(
-   SCIP_NLHDLR*          nlhdlr,            /**< nonlinear handler */
+   SCIP_NLHDLR*          nlhdlr,             /**< nonlinear handler */
    SCIP_DECL_NLHDLRFREEEXPRDATA((*freeexprdata)) /**< nonlinear handler expression data free callback (can be NULL if data does not need to be freed) */
 );
 
@@ -97,6 +97,13 @@ void SCIPnlhdlrSetSepa(
    SCIP_DECL_NLHDLREXITSEPA((*exitsepa))     /**< separation deinitialization callback (can be NULL) */
 );
 
+/** sets the solution linearization callback of a nonlinear handler */
+SCIP_EXPORT
+void SCIPnlhdlrSetSollinearize(
+   SCIP_NLHDLR*          nlhdlr,             /**< nonlinear handler */
+   SCIP_DECL_NLHDLRSOLLINEARIZE((*sollinearize))   /**< solution linearization callback */
+);
+
 /** gives name of nonlinear handler */
 SCIP_EXPORT
 const char* SCIPnlhdlrGetName(
@@ -169,6 +176,12 @@ SCIP_Bool SCIPnlhdlrHasEstimate(
    SCIP_NLHDLR*          nlhdlr              /**< nonlinear handler */
 );
 
+/** returns whether nonlinear handler implements the solution linearization callback */
+SCIP_EXPORT
+SCIP_Bool SCIPnlhdlrHasSollinearize(
+   SCIP_NLHDLR*          nlhdlr              /**< nonlinear handler */
+);
+
 /** compares two nonlinear handlers by detection priority
  *
  * if handlers have same detection priority, then compare by name
@@ -185,6 +198,7 @@ SCIP_DECL_SORTPTRCOMP(SCIPnlhdlrComp);
 #define SCIPnlhdlrSetInitExit(nlhdlr, init_, exit_)       do { (nlhdlr)->init = init_; nlhdlr->exit = exit_; } while (FALSE)
 #define SCIPnlhdlrSetProp(nlhdlr, inteval_, reverseprop_) do { (nlhdlr)->inteval = inteval_; nlhdlr->reverseprop = reverseprop_; } while (FALSE)
 #define SCIPnlhdlrSetSepa(nlhdlr, initsepa_, enfo_, estimate_, exitsepa_) do { (nlhdlr)->initsepa = initsepa_; (nlhdlr)->enfo = enfo_; (nlhdlr)->estimate = estimate_; (nlhdlr)->exitsepa = exitsepa_; } while (FALSE);
+#define SCIPnlhdlrSetSollinearize(nlhdlr, sollinearize_)  (nlhdlr)->sollinearize = sollinearize_
 #define SCIPnlhdlrGetName(nlhdlr) (nlhdlr)->name
 #define SCIPnlhdlrGetDesc(nlhdlr) (nlhdlr)->desc
 #define SCIPnlhdlrGetDetectPriority(nlhdlr) (nlhdlr)->detectpriority
@@ -197,6 +211,7 @@ SCIP_DECL_SORTPTRCOMP(SCIPnlhdlrComp);
 #define SCIPnlhdlrHasExitSepa(nlhdlr) ((nlhdlr)->exitsepa != NULL)
 #define SCIPnlhdlrHasEnfo(nlhdlr) ((nlhdlr)->enfo != NULL)
 #define SCIPnlhdlrHasEstimate(nlhdlr) ((nlhdlr)->estimate != NULL)
+#define SCIPnlhdlrHasSollinearize(nlhdlr) ((nlhdlr)->sollinearize != NULL)
 #endif
 
 /** @} */
